import { useState, useEffect, useRef } from 'react'

import { getStateFn, setStateFn } from '../index.d'

import { isFunction } from './utils'
import useSingleInstanceVar from './useSingleInstanceVar'

// 让你可以安全地使用 react 的 state，它的值就是你想要的值，
// 而不是陈旧的值。并且也拥有了 callback 的能力。
function useStateCB<T> (initialState: T): [getStateFn<T>, setStateFn<T>] {
  const [state, setState] = useState<T>(initialState)
  const _stateRef = useRef(isFunction(initialState) ? initialState() : initialState)
  const _callbackRef = useRef<any>(null)

  useEffect(() => {
    if (_callbackRef.current) {
      _callbackRef.current(state)
      _callbackRef.current = null
    }
  }, [state])

  const newSetState = (newState: any, callback: any) => {
    if (callback) _callbackRef.current = callback
    _stateRef.current = newState
    setState(newState)
  }

  const getState = () => {
    return _stateRef.current
  }

  return [getState, newSetState]
}

export default useStateCB
